-- draws the list of all the directories under "gfx"
function drawDirList(dirs, cur)
for i=1,#dirs do
	if i == cur then love.graphics.setColor(128, 128, 255) else love.graphics.setColor(255, 255, 255) end
	love.graphics.print(dirs[i].name, 30+(i-1)*80, 50)
	love.graphics.setColor(255, 255, 255)
end
end

-- returns a list of all the files inside a specific directory (must be under "gfx")
function getFileList(dir)
local o = love.filesystem.enumerate("gfx/" .. dir)
o[0] = "<none>"
return o
end

-- draws the list retrieved with the previous function
function drawFileList(dir, cur)
local x,y = 100, 300
for i=-2,2 do
if dir[cur+i] ~= nil then
	love.graphics.setColor(255, 255, 255, 255-(math.abs(i)*100))
	love.graphics.print(dir[cur+i], x, y+20*i)
end
end
love.graphics.setColor(255, 255, 255, 255)
end

-- returns a table with all the quads of a specific image.
-- the format must be 4 horizontal quads, 8 vertical quads, all 32x32
-- the return format is var[state][frame]

function getPreview(img)
if (love.filesystem.exists(img) == true) then
	local o = {}
	o.img = love.graphics.newImage(img)
	o.img:setFilter("nearest", "nearest")
	o.anim = {}
	for i=1,(love.graphics.getWidth(o.img)/32) do
		o[i] = {}
		for ii=1,(love.graphics.getHeight(o.img)/32) do
			o[i][ii] = love.graphics.newQuad((i-1)*32, (ii-1)*32, 32, 32, o.img:getWidth(), o.img:getHeight())
		end
	end
return o
else return nil end
end

function drawColorSliders()
local cred = baseDir[dirCursor].color[1]
local cgreen = baseDir[dirCursor].color[2]
local cblue = baseDir[dirCursor].color[3]
local calpha = baseDir[dirCursor].color[4]
love.graphics.print("Color", 100, 390)
love.graphics.setColor(cred, 255-cred, 255-cred, 255)
love.graphics.print(cred, 370, 415)
love.graphics.rectangle("fill", 100, 420, 255, 5)

love.graphics.setColor(255-cgreen, cgreen, 255-cgreen, 255)
love.graphics.print(cgreen, 370, 445)
love.graphics.rectangle("fill", 100, 450, 255, 5)

love.graphics.setColor(255-cblue, 255-cblue, cblue, 255)
love.graphics.print(cblue, 370, 475)
love.graphics.rectangle("fill", 100, 480, 255, 5)

love.graphics.setColor(255, 255, 255, 255)
love.graphics.print(calpha, 370, 505)
love.graphics.rectangle("fill", 100, 510, 255, 5)


--red
love.graphics.rectangle("fill", 100+cred, 410, 10, 20)
--green
love.graphics.rectangle("fill", 100+cgreen, 440, 10, 20)
--blue
love.graphics.rectangle("fill", 100+cblue, 470, 10, 20)
--alpha
love.graphics.rectangle("fill", 100+calpha, 500, 10, 20)

love.graphics.setColor(cred, cgreen, cblue, calpha)
love.graphics.rectangle("fill", 400, 350, 32, 32)
love.graphics.setColor(255, 255, 255, 255)

end

function drawSaveButton()
love.graphics.rectangle("line", 670, 342, 100, 30)
love.graphics.print("Save Image", 680, 350)
end

function love.load()
local a = love.filesystem.enumerate("gfx")
baseDir = {}
for i=1,#a do
	baseDir[i] = {}
	baseDir[i].name = a[i]
	baseDir[i].cursor = 0
	baseDir[i].preview = nil
	baseDir[i].previmg = nil
	baseDir[i].color = {255, 255, 255, 255}
end
dirCursor = 1

oldMenuCursor = 1
menuCursor = baseDir[dirCursor].cursor

loopCount = 0
frameCount = 1

keyCount = 0
end

function love.keypressed(key)
if key == "right" then 
	if dirCursor < #baseDir then dirCursor = dirCursor + 1 else dirCursor = 1 end
	menuCursor = baseDir[dirCursor].cursor
end
if key == "left" then 
	if dirCursor > 1 then dirCursor = dirCursor - 1 else dirCursor = #baseDir end
	menuCursor = baseDir[dirCursor].cursor
end
if key == "down" then 
	if menuCursor < #menuList then menuCursor = menuCursor + 1 else menuCursor = 0 end
	baseDir[dirCursor].cursor = menuCursor
	if love.filesystem.exists("gfx/" .. baseDir[dirCursor].name .. "/" .. menuList[menuCursor]) then
	baseDir[dirCursor].previmg = love.graphics.newImage("gfx/" .. baseDir[dirCursor].name .. "/" .. menuList[menuCursor])
	baseDir[dirCursor].previmg:setFilter("nearest", "nearest")
	else
	baseDir[dirCursor].previmg = nil
	baseDir[dirCursor].preview = nil
	end
	baseDir[dirCursor].preview = getPreview("gfx/" .. baseDir[dirCursor].name .. "/" .. menuList[menuCursor], frameCount)
end
if key == "up" then 
	if menuCursor > 0 then menuCursor = menuCursor - 1 else menuCursor = #menuList end
	baseDir[dirCursor].cursor = menuCursor
	if love.filesystem.exists("gfx/" .. baseDir[dirCursor].name .. "/" .. menuList[menuCursor]) then
	baseDir[dirCursor].previmg = love.graphics.newImage("gfx/" .. baseDir[dirCursor].name .. "/" .. menuList[menuCursor])
	baseDir[dirCursor].previmg:setFilter("nearest", "nearest")
	else
	baseDir[dirCursor].previmg = nil
	baseDir[dirCursor].preview = nil
	end
	baseDir[dirCursor].preview = getPreview("gfx/" .. baseDir[dirCursor].name .. "/" .. menuList[menuCursor], frameCount)
end
end

function love.update(dt)
if (loopCount < 10) then
	loopCount = loopCount + 100*dt
else
	if frameCount < 8 then
		frameCount = frameCount + 1
	else
		frameCount = 1
	end
	loopCount = 0
end

if love.mouse.isDown("l") then
	local cred = baseDir[dirCursor].color[1]
	local cgreen = baseDir[dirCursor].color[2]
	local cblue = baseDir[dirCursor].color[3]
	local calpha = baseDir[dirCursor].color[4]
	local mousex = love.mouse.getX()
	local mousey = love.mouse.getY()
	if mousex > 90 and mousex < 365 then
	if mousey >= 410 and mousey <= 430 then
			if mousex-100 < 0 then baseDir[dirCursor].color[1] = 0
			elseif mousex-100 > 255 then baseDir[dirCursor].color[1] = 255
			else baseDir[dirCursor].color[1] = mousex-100 end
	elseif mousey >= 440 and mousey <= 460 then
			if mousex-100 < 0 then baseDir[dirCursor].color[2] = 0
			elseif mousex-100 > 255 then baseDir[dirCursor].color[2] = 255
			else baseDir[dirCursor].color[2] = mousex-100 end
	elseif mousey >= 470 and mousey <= 490 then
			if mousex-100 < 0 then baseDir[dirCursor].color[3] = 0
			elseif mousex-100 > 255 then baseDir[dirCursor].color[3] = 255
			else baseDir[dirCursor].color[3] = mousex-100 end
	elseif mousey >= 500 and mousey <= 520 then
			if mousex-100 < 0 then baseDir[dirCursor].color[4] = 0
			elseif mousex-100 > 255 then baseDir[dirCursor].color[4] = 255
			else baseDir[dirCursor].color[4] = mousex-100 end
	end
	end

end

if oldDirCursor ~= dirCursor then
	menuList = getFileList(baseDir[dirCursor].name)
end
oldDirCursor = dirCursor
end

function love.draw()
drawDirList(baseDir, dirCursor)
drawFileList(menuList, menuCursor)
drawColorSliders()
love.graphics.setColor(255, 0, 255)
love.graphics.rectangle("fill", 500, 300, 128, 256)
love.graphics.setColor(255, 255, 255)
for a=1,#baseDir do
	if baseDir[a].previmg and baseDir[a].preview then
		love.graphics.setColor(baseDir[a].color[1], baseDir[a].color[2], baseDir[a].color[3], baseDir[a].color[4])
		for b=1,4 do
			love.graphics.drawq(baseDir[a].previmg, baseDir[a].preview[b][frameCount], 300+(100*b), 150, 0, 2, 2) 
		end
		love.graphics.draw(baseDir[a].previmg, 500, 300)
	end
	love.graphics.setColor(255, 255, 255, 255)
end
drawSaveButton()
end